@@ -2,6 +2,7 @@ from random import randint
 from re import findall
 
 def create_key():
+    # generate key
     key = str(randint(0,99999999999999999999999999999999999999999999999999))
     key = [i for i in key]
 
@@ -101,7 +102,7 @@ def decipher(code,key):
     
 def a_credits():
     print("\
-=== Credits ==\
+=== Credits ==\n\
 Thank you to the repl.it community for providing such amazing services for free.\n\
 Thank you to Atticus Kuhn for poiting out safety concerns on the project.\n\
 Thank you StealthHydra179 (https://repl.it/@StealthHydra179), for being the only person who cared about programming in my school.\n\
